##  Onboarding Progress and Data Quality
The onboarding process is structured into goals, milestones, and tasks, which enables you to complete each step methodically and track your progress. Additionally, you can use best practice metrics to benchmark the data quality of your workspace.
### Goals
A goal represents a significant step or phase in the onboarding process, focusing on achieving a specific outcome or result. It sets a broad objective that is accomplished by completing a series of milestones and associated tasks. A goal is marked as completed in the following cases:
  * When at least one milestone is completed and all other milestones are skipped.
  * You've completed the entire journey, which marks all open goals as completed.


### Milestones
A milestone consists of several tasks and associated best practice metrics. You can complete or skip the entire milestone. The status of a milestone automatically updates based on the status of associated tasks.
  * When all tasks within a milestone are completed or skipped, the milestone status changes to completed or skipped, respectively.
  * When you mark a milestone as completed or skipped, all open tasks are marked as completed or skipped, respectively.
  * When at least one task is completed and all other tasks are skipped, the milestone status changes to completed.


### Tasks
Tasks are the smallest units of the onboarding process, each containing specific action items. Each task includes a link to a detailed guide for that process step.
You can mark a task as completed or skipped, which enables you to track your progress. However, remember that tasks should be skipped sparingly. If needed, you can reopen a task by clicking Reopen.
### Best-Practice Metrics
In addition to tracking the completion of tasks, milestones, and goals, you can benchmark the quality of your workspace data against SAP LeanIX best practices during onboarding. For more information, see [Understanding Best-Practice Metrics](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758a23c7a441014b785d6548482893a__understanding_best_practice_metrics).
